@@ -1,6 +1,7 @@
-#!/usr/bin/python
+#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
+# Copyright (c) 2014 Daniel Standage <daniel.standage@gmail.com>
 # Copyright (c) 2008 Sascha Steinbiss <steinbiss@zbh.uni-hamburg.de>
 # Copyright (c) 2008 Center for Bioinformatics, University of Hamburg
 #
@@ -48,7 +49,7 @@ class FeatureIndex:
         err = Error()
         result = []
         rval = gtlib.gt_feature_index_get_features_for_seqid(self.fi,
-                seqid, err)
+                seqid, err._as_parameter_)
         if rval:
             a = Array(rval, True)
             for i in range(a.size()):
@@ -62,7 +63,7 @@ class FeatureIndex:
     def add_gff3file(self, filename):
         err = Error()
         rval = gtlib.gt_feature_index_add_gff3file(self.fi, filename,
-                err)
+                err._as_parameter_)
         if rval != 0:
             gterror(err)
 
@@ -71,7 +72,7 @@ class FeatureIndex:
         val = c_int()
         err = Error()
         ret = gtlib.gt_feature_index_has_seqid(self.fi, byref(val),
-                seqid, err)
+                seqid, err._as_parameter_)
         if ret != 0:
             gterror(err)
         else:
@@ -79,7 +80,7 @@ class FeatureIndex:
 
     def get_first_seqid(self):
         err = Error()
-        str = gtlib.gt_feature_index_get_first_seqid(self.fi, err)
+        str = gtlib.gt_feature_index_get_first_seqid(self.fi, err._as_parameter_)
         if str == None:
             if err.is_set():
                 gterror(err)
@@ -88,7 +89,7 @@ class FeatureIndex:
     def get_seqids(self):
         result = []
         err = Error()
-        stra = StrArray(gtlib.gt_feature_index_get_seqids(self.fi, err))
+        stra = StrArray(gtlib.gt_feature_index_get_seqids(self.fi, err._as_parameter_))
         if stra == None:
             gterror(err)
         for i in range(stra.size()):
@@ -112,8 +113,8 @@ class FeatureIndex:
         a = Array.create()
         err = Error()
         rng = Range(start, end)
-        rval = gtlib.gt_feature_index_get_features_for_range(self.fi, a,
-                seqid, byref(rng), err)
+        rval = gtlib.gt_feature_index_get_features_for_range(self.fi,
+                a._as_parameter_, seqid, byref(rng), err._as_parameter_)
         if rval != 0:
             gterror(err)
         result = []
@@ -125,19 +126,26 @@ class FeatureIndex:
     def register(cls, gtlib):
         from ctypes import c_char_p, c_void_p, c_int, POINTER
         gtlib.gt_feature_index_get_features_for_seqid.restype = c_void_p
+        gtlib.gt_feature_index_get_features_for_seqid.argtypes = [c_void_p,
+                c_char_p, c_void_p]
+        gtlib.gt_feature_index_add_gff3file.restype = c_int
         gtlib.gt_feature_index_add_gff3file.argtypes = [c_void_p,
-                c_char_p, Error]
+                c_char_p, c_void_p]
         gtlib.gt_feature_index_get_first_seqid.restype = c_char_p
-        gtlib.gt_feature_index_get_first_seqid.argtypes = [c_void_p, Error]
-        gtlib.gt_feature_index_get_seqids.restype = c_int
-        gtlib.gt_feature_index_get_first_seqid.argtypes = [c_void_p, Error]
+        gtlib.gt_feature_index_get_first_seqid.argtypes = [c_void_p, c_void_p]
+        gtlib.gt_feature_index_get_seqids.restype = c_void_p
+        gtlib.gt_feature_index_get_seqids.argtypes = [c_void_p, c_void_p]
         gtlib.gt_feature_index_has_seqid.restype = c_int
         gtlib.gt_feature_index_has_seqid.argtypes = [c_void_p, POINTER(c_int),
-                c_char_p, Error]
+                c_char_p, c_void_p]
+        gtlib.gt_feature_index_get_range_for_seqid.restype = c_int
         gtlib.gt_feature_index_get_range_for_seqid.argtypes = [c_void_p,
                 POINTER(Range), c_char_p]
+        gtlib.gt_feature_index_get_features_for_range.restype = c_int
         gtlib.gt_feature_index_get_features_for_range.argtypes = [c_void_p,
-                Array, c_char_p, POINTER(Range), Error]
+                c_void_p, c_char_p, POINTER(Range), c_void_p]
+        gtlib.gt_feature_index_delete.restype = None
+        gtlib.gt_feature_index_delete.argtypes = [c_void_p]
 
     register = classmethod(register)
 
@@ -155,6 +163,13 @@ class FeatureIndexMemory(FeatureIndex):
 
     from_param = classmethod(from_param)
 
+    def register(cls, gtlib):
+        from ctypes import c_void_p
+        gtlib.gt_feature_index_memory_new.restype = c_void_p
+        gtlib.gt_feature_index_memory_new.argtypes = []
+
+    register = classmethod(register)
+
 
 class FeatureIndexFromPtr(FeatureIndex):
 
