@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2011 Gordon Gremme <gremme@zbh.uni-hamburg.de>
+  Copyright (c) 2006-2011 Gordon Gremme <gordon@gremme.org>
   Copyright (c) 2006-2008 Center for Bioinformatics, University of Hamburg
 
   Permission to use, copy, modify, and distribute this software for any
@@ -119,6 +119,9 @@ GtOPrval        gt_option_parser_parse(GtOptionParser *option_parser,
                                        int argc, const char **argv,
                                        GtShowVersionFunc version_func,
                                        GtError *err);
+/* Reset all options set in <op> to the default values specified at
+   option parser creation time. */
+void            gt_option_parser_reset(GtOptionParser *op);
 /* Delete <option_parser>. */
 void            gt_option_parser_delete(GtOptionParser *option_parser);
 
@@ -216,36 +219,58 @@ GtOption*       gt_option_new_uint_min_max(const char *option_string,
                                            unsigned int maximum_value);
 /* Return a new <GtOption> with the given <option_string>, <description>, and
    <default_value>. The result of the option parsing is stored in <value>. */
-GtOption*       gt_option_new_long(const char *option_string,
+GtOption*       gt_option_new_word(const char *option_string,
                                    const char *description,
-                                   long *value, long default_value);
+                                   GtWord *value, GtWord default_value);
 /* Return a new <GtOption> with the given <option_string>, <description>, and
    <default_value>. The result of the option parsing is stored in <value>. */
-GtOption*       gt_option_new_ulong(const char *option_string,
+GtOption*       gt_option_new_uword(const char *option_string,
                                     const char *description,
-                                    unsigned long *value,
-                                    unsigned long default_value);
+                                    GtUword *value,
+                                    GtUword default_value);
 /* Return a new <GtOption> with the given <option_string>, <description>, and
    <default_value>. The result of the option parsing is stored in <value>.
   The argument to this option must at least have the <minimum_value>. */
-GtOption*       gt_option_new_ulong_min(const char *option_string,
+GtOption*       gt_option_new_uword_min(const char *option_string,
                                         const char *description,
-                                        unsigned long *value,
-                                        unsigned long default_value,
-                                        unsigned long minimum_value);
+                                        GtUword *value,
+                                        GtUword default_value,
+                                        GtUword minimum_value);
 /* Return a new <GtOption> with the given <option_string>, <description>, and
    <default_value>. The result of the option parsing is stored in <value>.
   The argument to this option must at least have the <minimum_value> and at most
   the <maximum_value>. */
+GtOption*       gt_option_new_uword_min_max(const char *option_string,
+                                            const char *description,
+                                            GtUword *value,
+                                            GtUword default_value,
+                                            GtUword minimum_value,
+                                            GtUword maximum_value);
+/* Deprecated. Usage identical to <gt_option_new_word>. */
+GtOption*       gt_option_new_long(const char *option_string,
+                                   const char *description,
+                                   GtWord *value, GtWord default_value);
+/* Deprecated. Usage identical to <gt_option_new_uword>. */
+GtOption*       gt_option_new_ulong(const char *option_string,
+                                    const char *description,
+                                    GtUword *value,
+                                    GtUword default_value);
+/* Deprecated. Usage identical to <gt_option_new_uword_min>. */
+GtOption*       gt_option_new_ulong_min(const char *option_string,
+                                        const char *description,
+                                        GtUword *value,
+                                        GtUword default_value,
+                                        GtUword minimum_value);
+/* Deprecated. Usage identical to <gt_option_new_uword_min_max>. */
 GtOption*       gt_option_new_ulong_min_max(const char *option_string,
                                             const char *description,
-                                            unsigned long *value,
-                                            unsigned long default_value,
-                                            unsigned long minimum_value,
-                                            unsigned long maximum_value);
+                                            GtUword *value,
+                                            GtUword default_value,
+                                            GtUword minimum_value,
+                                            GtUword maximum_value);
 /* Return a new <GtOption> with the given <option_string>, <description>, and
    <default_value>. The result of the option parsing is stored in <value>.
-   If <default_value> equals <NULL>, <GT_UNDEF_LONG> will be used as the default
+   If <default_value> equals <NULL>, <GT_UNDEF_WORD> will be used as the default
    start and end point of <value>. */
 GtOption*       gt_option_new_range(const char *option_string,
                                     const char *description,
@@ -259,8 +284,8 @@ GtOption*       gt_option_new_range_min_max(const char *option_string,
                                             const char *description,
                                             GtRange *value,
                                             GtRange *default_value,
-                                            unsigned long minimum_value,
-                                            unsigned long maximum_value);
+                                            GtUword minimum_value,
+                                            GtUword maximum_value);
 /* Return a new <GtOption> with the given <option_string>, <description>, and
    <default_value>. The result of the option parsing is stored in <value>. */
 GtOption*       gt_option_new_string(const char *option_string,
@@ -278,8 +303,9 @@ GtOption*       gt_option_new_choice(const char *option_string,
                                      const char *description, GtStr *value,
                                      const char *default_value,
                                      const char **domain);
-/* Return a new <GtOption> with the given <option_string>, <description>, and
-   <default_value>. The result of the option parsing are stored in <value>. */
+/* Return a new <GtOption> with the given <option_string>, <description>. The
+   result of the option parsing is stored in the <GtStr> object <filename>.
+   <filename> may not be NULL! */
 GtOption*       gt_option_new_filename(const char *option_string,
                                        const char *description,
                                        GtStr *filename);
@@ -297,7 +323,7 @@ GtOption*       gt_option_new_verbose(bool *value);
 /* Return a new width <GtOption> object: <-width>, "set output width for FASTA
    sequence printing (0 disables formatting)", default is 0.
    The result of the option parsing is stored in <value> */
-GtOption*       gt_option_new_width(unsigned long *value);
+GtOption*       gt_option_new_width(GtUword *value);
 /* Increase the reference count for <option> and return it. */
 GtOption*       gt_option_ref(GtOption *option);
 /* Return the name of <option> */
@@ -347,7 +373,7 @@ void            gt_option_delete(GtOption*);
 /* Parse the argument to option -memlimit. Could be made into
    a special parser, but I do not know how. SK. 2011-09-19 */
 
-int gt_option_parse_spacespec(unsigned long *maximumspace,
+int gt_option_parse_spacespec(GtUword *maximumspace,
                               const char *optname,
                               const GtStr *memlimit,
                               GtError *err);
