@@ -17,9 +17,7 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#ifndef S_SPLINT_S
 #include <ctype.h>
-#endif
 #include <string.h>
 #include "core/assert_api.h"
 #include "core/array.h"
@@ -283,7 +281,6 @@ static inline unsigned int gt_alignment_show_advance(unsigned int pos,
   return pos;
 }
 
-/* XXX: add width parameter and format the GtAlignment accordingly */
 void gt_alignment_show(const GtAlignment *alignment, FILE *fp,
                        unsigned int width)
 {
