@@ -15,10 +15,8 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#ifndef S_SPLINT_S
 #include <sys/stat.h>
 #include <unistd.h>
-#endif
 
 #include "core/assert_api.h"
 #include "core/compat.h"
