@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2011 Sascha Kastens <sascha.kastens@studium.uni-hamburg.de>
+  Copyright (c) 2011 Sascha Kastens <mail@skastens.de>
   Copyright (c) 2011 Center for Bioinformatics, University of Hamburg
 
   Permission to use, copy, modify, and distribute this software for any
@@ -29,9 +29,9 @@ const GtMatchClass* gt_match_blast_class(void);
 
 struct GtMatchBlast {
   GtMatch parent_instance;
-  long double evalue;
+  double evalue;
   float bitscore;
-  unsigned long ali_length;
+  GtUword ali_length;
   double similarity;
 };
 
@@ -65,13 +65,13 @@ const GtMatchClass* gt_match_blast_class()
 
 GtMatch* gt_match_blast_new(char *seqid1,
                             char *seqid2,
-                            unsigned long start_seq1,
-                            unsigned long end_seq1,
-                            unsigned long start_seq2,
-                            unsigned long end_seq2,
+                            GtUword start_seq1,
+                            GtUword end_seq1,
+                            GtUword start_seq2,
+                            GtUword end_seq2,
                             double evalue,
                             float bitscore,
-                            unsigned long length,
+                            GtUword length,
                             double similarity,
                             GtMatchDirection dir)
 {
@@ -87,7 +87,7 @@ GtMatch* gt_match_blast_new(char *seqid1,
   return match;
 }
 
-void gt_match_blast_set_evalue(GtMatchBlast *mb, long double evalue)
+void gt_match_blast_set_evalue(GtMatchBlast *mb, double evalue)
 {
   gt_assert(mb);
   mb->evalue = evalue;
@@ -99,7 +99,7 @@ void gt_match_blast_set_bitscore(GtMatchBlast *mb, float bits)
   mb->bitscore = bits;
 }
 
-void gt_match_blast_set_align_length(GtMatchBlast *mb, unsigned long length)
+void gt_match_blast_set_align_length(GtMatchBlast *mb, GtUword length)
 {
   gt_assert(mb);
   mb->ali_length = length;
@@ -111,7 +111,7 @@ void gt_match_blast_set_similarity(GtMatchBlast *mb, double similarity)
   mb->similarity = similarity;
 }
 
-long double gt_match_blast_get_evalue(GtMatchBlast *mb)
+double gt_match_blast_get_evalue(GtMatchBlast *mb)
 {
   gt_assert(mb);
   return mb->evalue;
@@ -123,7 +123,7 @@ float gt_match_blast_get_bitscore(GtMatchBlast *mb)
   return mb->bitscore;
 }
 
-unsigned long gt_match_blast_get_align_length(GtMatchBlast *mb)
+GtUword gt_match_blast_get_align_length(GtMatchBlast *mb)
 {
   gt_assert(mb);
   return mb->ali_length;
