@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2008, 2011-2012 Gordon Gremme <gremme@zbh.uni-hamburg.de>
+  Copyright (c) 2008, 2011-2012 Gordon Gremme <gordon@gremme.org>
   Copyright (c) 2008            Center for Bioinformatics, University of Hamburg
 
   Permission to use, copy, modify, and distribute this software for any
@@ -34,6 +34,10 @@ bool           gt_type_checker_is_valid(GtTypeChecker *type_checker,
 bool           gt_type_checker_is_partof(GtTypeChecker *type_checker,
                                          const char *parent_type,
                                          const char *child_type);
+/* Return <true> if <child_type> is a <parent_type>, <false> otherwise. */
+bool           gt_type_checker_is_a(GtTypeChecker *type_checker,
+                                    const char *parent_type,
+                                    const char *child_type);
 /* Decrease the reference count for <type_checker> or delete it, if this was the
    last reference. */
 void           gt_type_checker_delete(GtTypeChecker *type_checker);
