@@ -85,7 +85,7 @@ typedef struct {
   GtArray *fwd_hits,
           *rev_hits;
   GtUword last_array_size_fwd,
-                last_array_size_rev;
+          last_array_size_rev;
   double best_rev,
          best_fwd;
   char *modelname;
@@ -263,11 +263,10 @@ static inline int pdom_parser_get_next_line(char *buf, FILE *instream,
 }
 
 #ifndef _WIN32
-static int gt_ltrdigest_pdom_visitor_parse_statistics(GT_UNUSED
-                                                      GtLTRdigestPdomVisitor
-                                                                            *lv,
-                                                     char *buf, FILE *instream,
-                                                     GtError *err)
+static int gt_ltrdigest_pdom_visitor_parse_statistics(
+                                           GT_UNUSED GtLTRdigestPdomVisitor *lv,
+                                           char *buf, FILE *instream,
+                                           GtError *err)
 {
   int had_err = 0;
   gt_assert(lv && instream);
@@ -290,7 +289,7 @@ static int gt_ltrdigest_pdom_visitor_parse_scores(GT_UNUSED
   had_err = pdom_parser_get_next_line(buf, instream, err);
   gt_assert(had_err || buf != NULL);
   if (!had_err && strncmp("Scores", buf, (size_t) 6) != 0) {
-    gt_error_set(err, "expected 'Scores:' at beginning of new scores "
+    gt_error_set(err, "expected 'Scores' at beginning of new scores "
                       "section, '%s' read instead", buf);
     had_err = -1;
   }
@@ -322,13 +321,12 @@ GT_UNUSED static void gt_ltrdigest_pdom_visitor_add_aaseq(const char *str,
 }
 
 #ifndef _WIN32
-static int gt_ltrdigest_pdom_visitor_parse_alignments(GT_UNUSED
-                                                      GtLTRdigestPdomVisitor
-                                                                            *lv,
-                                                     GtHMMERParseStatus *status,
-                                                     char *buf,
-                                                     FILE *instream,
-                                                     GtError *err)
+static int gt_ltrdigest_pdom_visitor_parse_alignments(
+                                           GT_UNUSED GtLTRdigestPdomVisitor *lv,
+                                           GtHMMERParseStatus *status,
+                                           char *buf,
+                                           FILE *instream,
+                                           GtError *err)
 {
   int had_err = 0, cur_domain = GT_UNDEF_INT, line = GT_UNDEF_INT;
   int mod_val = 4;
@@ -391,8 +389,8 @@ static int gt_ltrdigest_pdom_visitor_parse_alignments(GT_UNUSED
 #endif
 
 #ifndef _WIN32
-static int gt_ltrdigest_pdom_visitor_parse_domainhits(GtLTRdigestPdomVisitor
-                                                                            *lv,
+static int gt_ltrdigest_pdom_visitor_parse_domainhits(
+                                                     GtLTRdigestPdomVisitor *lv,
                                                      GtHMMERParseStatus *status,
                                                      char *buf,
                                                      FILE *instream,
@@ -1043,7 +1041,7 @@ GtNodeVisitor* gt_ltrdigest_pdom_visitor_new(GtPdomModelSet *model,
     }
     gt_str_append_cstr(cmd, " ");
     gt_str_append_cstr(cmd, gt_pdom_model_set_get_filename(model));
-    gt_str_append_cstr(cmd, " -");
+    gt_str_append_cstr(cmd, " -"); /* stdin */
     lv->cmdline = cmd;
     lv->args = gt_cstr_split(gt_str_get(lv->cmdline), ' ');
     gt_log_log("HMMER cmdline: %s", gt_str_get(cmd));
