@@ -144,15 +144,15 @@ static void gt_firstcodes_accumulatecounts_flush(void *data)
                                          fci->differentcodes,
                                          fci->tab.differencemask,
                                          fci->binsearchcache,
-                                         fci->buf.spaceGtUlong[0]);
+                                         fci->buf.spaceGtUword[0]);
     if (foundindex != ULONG_MAX)
     {
       fci->firstcodehits
         += gt_firstcodes_accumulatecounts_merge(&fci->tab,
                                                 fci->allfirstcodes,
                                                 fci->differentcodes,
-                                                fci->buf.spaceGtUlong,
-                                                fci->buf.spaceGtUlong
+                                                fci->buf.spaceGtUword,
+                                                fci->buf.spaceGtUword
                                                 + fci->buf.nextfree - 1,
                                                 foundindex,
                                                 foundcode);
@@ -192,12 +192,12 @@ const GtUword *gt_firstcodes_find_insert(const GtFirstcodesinfo *fci,
 
 static GtUword gt_firstcodes_insertsuffixes_merge(
                                         GtFirstcodesinfo *fci,
-                                        const GtUlongPair *querystream_fst,
+                                        const GtUwordPair *querystream_fst,
                                         const GtUword *subjectstream_fst)
 {
   GtUword found = 0, idx;
-  const GtUlongPair *query = querystream_fst,
-                    *querystream_lst = fci->buf.spaceGtUlongPair +
+  const GtUwordPair *query = querystream_fst,
+                    *querystream_lst = fci->buf.spaceGtUwordPair +
                                        fci->buf.nextfree - 1;
   const GtUword *subject = subjectstream_fst,
                       *subjectstream_lst = fci->allfirstcodes +
@@ -239,11 +239,11 @@ static void gt_firstcodes_insertsuffixes_flush(void *data)
     gt_assert(fci->allfirstcodes != NULL);
     fci->codebuffer_total += fci->buf.nextfree;
     gt_radixsort_inplace_sort(fci->radixsort_codepos,fci->buf.nextfree);
-    ptr = gt_firstcodes_find_insert(fci,fci->buf.spaceGtUlongPair[0].a);
+    ptr = gt_firstcodes_find_insert(fci,fci->buf.spaceGtUwordPair[0].a);
     if (ptr != NULL)
     {
       fci->firstcodeposhits
-        += gt_firstcodes_insertsuffixes_merge(fci,fci->buf.spaceGtUlongPair,
+        += gt_firstcodes_insertsuffixes_merge(fci,fci->buf.spaceGtUwordPair,
                                               ptr);
     }
     fci->flushcount++;
@@ -734,8 +734,8 @@ static int gt_firstcodes_init(GtFirstcodesinfo *fci,
   fci->spmsuftab = NULL;
   fci->radixsort_code = NULL;
   fci->radixsort_codepos = NULL;
-  fci->buf.spaceGtUlongPair = NULL;
-  fci->buf.spaceGtUlong = NULL;
+  fci->buf.spaceGtUwordPair = NULL;
+  fci->buf.spaceGtUword = NULL;
   fci->mappedallfirstcodes = NULL;
   fci->mappedmarkprefix = NULL;
   fci->mappedleftborder = NULL;
@@ -891,7 +891,7 @@ static void gt_firstcodes_accumulatecounts_run(GtFirstcodesinfo *fci,
   }
   gt_assert(fci->buf.allocated > 0);
   fci->radixsort_code = gt_radixsort_new_ulong(fci->buf.allocated);
-  fci->buf.spaceGtUlong = gt_radixsort_space_ulong(fci->radixsort_code);
+  fci->buf.spaceGtUword = gt_radixsort_space_ulong(fci->radixsort_code);
   GT_FCI_ADDWORKSPACE(fci->fcsl,"radixsort_code",
                       gt_radixsort_size(fci->radixsort_code));
   fci->buf.fciptr = fci; /* as we need to give fci to the flush function */
@@ -1444,7 +1444,7 @@ int storefirstcodes_getencseqkmers_twobitencoding(const GtEncseq *encseq,
       fci.radixsort_codepos = gt_radixsort_new_ulongpair(fci.buf.allocated);
       GT_FCI_ADDWORKSPACE(fci.fcsl,"radixsort_codepos",
                           gt_radixsort_size(fci.radixsort_codepos));
-      fci.buf.spaceGtUlongPair
+      fci.buf.spaceGtUwordPair
         = gt_radixsort_space_ulongpair(fci.radixsort_codepos);
     }
     fci.codebuffer_total = 0;
@@ -1526,7 +1526,7 @@ int storefirstcodes_getencseqkmers_twobitencoding(const GtEncseq *encseq,
     gt_free(fci.allfirstcodes);
     fci.allfirstcodes = NULL;
     gt_Sfxmappedrangelist_delete(sfxmrlist);
-    fci.buf.spaceGtUlong = NULL;
+    fci.buf.spaceGtUword = NULL;
     gt_radixsort_delete(fci.radixsort_code);
   }
   gt_suftabparts_delete(suftabparts);
