@@ -1427,13 +1427,6 @@ Test do
   grep last_stderr, "ends with a blank, removing"
 end
 
-Name "gt gff3 -sortlines (missing -sort) "
-Keywords "gt_gff3 linesorting"
-Test do
-  run_test "#{$bin}gt gff3 -sortlines #{$testdata}eden.gff3", :retval => 1
-  grep last_stderr, "requires option \"-sort\""
-end
-
 Name "gt gff3 -sortlines (standard gene)"
 Keywords "gt_gff3 linesorting"
 Test do
@@ -1497,6 +1490,36 @@ Test do
   run "diff 1 3"
 end
 
+Name "gt gff3 -sortnum (standard gene)"
+Keywords "gt_gff3 numsorting"
+Test do
+  run_test "#{$bin}gt gff3 -sort -retainids #{$testdata}eden.gff3 > 1"
+  run_test "#{$bin}gt gff3 -sort -retainids -sortnum #{$testdata}eden.gff3"
+  run "diff #{last_stdout} 1"
+end
+
+Name "gt gff3 -sortnum (numeric seqids only)"
+Keywords "gt_gff3 numsorting"
+Test do
+  run_test "#{$bin}gt gff3 -sort -retainids -sortnum #{$testdata}gff3_numeric_only.gff3"
+  run "diff #{last_stdout} #{$testdata}gff3_numeric_only.out"
+end
+
+Name "gt gff3 -sortnum (mixed numeric + alphanumeric seqids)"
+Keywords "gt_gff3 numsorting"
+Test do
+  run_test "#{$bin}gt gff3 -sort -retainids -sortnum #{$testdata}gff3_numeric_mixed.gff3"
+  run "diff #{last_stdout} #{$testdata}gff3_numeric_mixed.out"
+end
+
+Name "gt gff3 -sortnum (implicit -sort)"
+Keywords "gt_gff3 numsorting"
+Test do
+  run_test "#{$bin}gt gff3 -sort -retainids -sortnum #{$testdata}gff3_numeric_a.gff #{$testdata}gff3_numeric_a.gff  > 1"
+  run_test "#{$bin}gt gff3 -retainids -sortnum #{$testdata}gff3_numeric_a.gff #{$testdata}gff3_numeric_a.gff "
+  run "diff #{last_stdout} 1"
+end
+
 Name "gt gff3 (double free regression)"
 Keywords "gt_gff3"
 Test do
