@@ -1,3 +1,5 @@
+require "fileutils"
+
 Name "gt seq nonexistent file"
 Keywords "gt_seq"
 Test do
@@ -106,7 +108,8 @@ end
   Name "gt seq test 3 out #{i}"
   Keywords "gt_seq"
   Test do
-    run_test "#{$bin}gt seq -showseqnum #{i} -width 70 #{$testdata}gt_bioseq_succ_3.fas"
+    FileUtils.copy("#{$testdata}gt_bioseq_succ_3.fas", ".")
+    run_test "#{$bin}gt seq -showseqnum #{i} -width 70 gt_bioseq_succ_3.fas"
     run "diff #{last_stdout} #{$testdata}gt_bioseq_succ_3.out#{i}"
   end
 end
@@ -130,7 +133,8 @@ end
 Name "gt seq test 3 stat"
 Keywords "gt_seq"
 Test do
-  run_test "#{$bin}gt seq -stat #{$testdata}gt_bioseq_succ_3.fas"
+  FileUtils.copy("#{$testdata}gt_bioseq_succ_3.fas", ".")
+  run_test "#{$bin}gt seq -stat gt_bioseq_succ_3.fas"
 end
 
 Name "gt seq test 3 stat (stdin)"
@@ -142,7 +146,9 @@ end
 Name "gt seq test multiple sequence files"
 Keywords "gt_seq"
 Test do
-  run_test "#{$bin}gt seq -recreate #{$testdata}gt_bioseq_succ_1.fas #{$testdata}gt_bioseq_succ_2.fas"
+  FileUtils.copy(["#{$testdata}gt_bioseq_succ_1.fas", "#{$testdata}gt_bioseq_succ_2.fas"],
+                 ".")
+  run_test "#{$bin}gt seq -recreate gt_bioseq_succ_1.fas gt_bioseq_succ_2.fas"
 end
 
 Name "gt seq test multiple sequence files (incl. stdin)"
