@@ -161,6 +161,7 @@ end
 require 'gt_bed_to_gff3_include'
 require 'gt_cds_include'
 require 'gt_chseqids_include'
+require 'gt_condenseq_include'
 require 'gt_condenser_include'
 require 'gt_consensus_sa_include'
 require 'gt_csa_include'
@@ -180,6 +181,7 @@ require 'gt_id_to_md5_include'
 require 'gt_include'
 require 'gt_inlineseq_include'
 require 'gt_interfeat_include'
+require 'gt_kmer_database_include'
 require 'gt_loccheck_include'
 require 'gt_ltrdigest_include'
 require 'gt_ltrharvest_include'
